Runtime values produced by evaluation.
In the pure untyped lambda calculus the only runtime value is a closure: a function body paired with the environment that was in scope when the enclosing lambda was evaluated.
Enums
- Value
- A runtime value.